% Initialisering for sat_obs_enkel.mdl
%--------------------------------

%Controller parameters robust stabilization
g = 20*5;        %lambda error gain

Gp = 19*[5     0     0;         %derivative error gain
         0     5     0;
         0     0     5];

Gr = 5*[20     0     0;         %derivative error gain
         0    20     0;
         0     0    20];


%Controller parameters passivity based adaptive
K_p = 22;        %lambda error gain

K_d = 2.5*[20     0     0;         %derivative error gain
            0    20     0;
            0     0    20];


%Controller parameters PD-feedback
Kp = 40*[2.5   0     0;          %Kp error gain
         0     2.5   0;
         0     0     2.5];

Kd = 5*[10     0     0;         %derivative error gain
         0    10     0;
         0     0    10];

   
%Number of sensors:
star = 1;

Ms = [22.0     0     0;         %Satellite inertia matrix
        0  32.3     0;
        0     0  34.7];

tau_t = [0.1 0.01 0.1]';
G = 6.67259*10^-11;             %Newton's gravitational constant: m^3*kg^-1*s^-2
Mm = 7.347673*10^22;            %Moon mass: kg
Dm = 3472*10^3;                 %Moon diameter in meters
R = Dm/2;                       %Distance Moon mass center to orbit in meters

w0 = sqrt(G*Mm/R^3);            %Orbital velocity satellite around moon
w_o_io = [0 -w0 0]';

%Initial integrator values
sat_eta_init = 0;
sat_eps_init = [sqrt(0.33) 0.33 sqrt(1-(0.33+0.33^2))]';

%-----Sensors------
%IMU
w_noise_power = 0.0001;
imu_max_err = 0.02;
imu_err_var = (imu_max_err/2)^2;

%Star trackers
star_max_err = 2.4*10^-6;
if star == 1
    star_err_var = (star_max_err/2)^2;
elseif star == 2
    star_err_var = ((star_max_err/2)^2)/2;
end

%Sun sensor
sun_max_err = 1/(4*60);
sun_err_var = (sun_max_err/2)^2;

%noise_arrays
sun_noise1 = 0*[1:100];
for i = 2:100;
sun_noise1(i) = sun_noise1(i-1)+(rand(1)*0.001-0.0005);
end

sun_noise2 = 0*[1:100];
for i = 2:100;
sun_noise2(i) = sun_noise2(i-1)+(rand(1)*0.001-0.0005);
end

sun_noise3 = 0*[1:100];
for i = 2:100;
sun_noise3(i) = sun_noise3(i-1)+(rand(1)*0.001-0.0005);
end

%Sun reference model
mu = 5.145/180*pi;          %Moons inclination with the earth's ecliptic

Re = 365*24*60*60;          %Earth rotation time in seconds
Rm = 30*24*60*60;           %Moon rotation time in seconds
Ro = 2*pi/w0;               %Satellite rotation time in seconds

AU = 149597870691;          %Astronomical Unit in meters
dist_se = AU;
dist_em = 0.0026*AU;
dist_mo = R;
Year = Re;

%Vik & Fossen observer
K1 = 0.4*[1 0 0; 0 1 0; 0 0 1];
K2 = 0.01*[4 0 0; 0 4 0; 0 0 4];
K3 = diag([1 1 1]);
K4 = diag([1 1 1 1 1 1]);
T1 = [0.1 0 0; 0 0.1 0; 0 0 0.1];
T2 = diag([0.1 0.1 0.1]);
T3 = diag([0.1 0.1 0.1 0.1 0.1 0.1]);
VFqinit = [1 0 0 0]';
VFbinit = [0.1 0.1 0]';
imu_scale_error_init = [0 0 0; 0 0 0; 0 0 0];
imu_align_error_init = [0 0 0 0 0 0]';

