% ExWindForce  plotting the wind forces and moment using Isherwoods (1972) formulas
%
% Author:    Thor I. Fossen
% Date:      10 September 2001
% Revisions: 6 May 2004: new values for A_T and A_L

%%%%%%%%% CASE 1 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
V_r = 20;  % wind speed (m/s)

L	      = 100;  % length overall (m)
B	      =  20;  % beam (m)
A_L       = 1000; % lateral projected area (m^2)
A_T       = 400;  % transverse projected area (m^2)
A_SS      = 100;  % lateral projected area of superstructure (m^2)
S	      = 50;  % length of perimeter of lateral projection of model (m)
		          % excluding waterline and slender bodies such as masts and ventilators (m)
C	      = 20;   % distance from bow of centroid of lateral projected area (m)
M	      = 1;    % number of distinct groups of masts or king posts seen in lateral
		          % projection; king posts close against the bridge front are not included

clf; figure(1)
i = 1; 

for gamma_r = 0:0.1:pi,
    [w_wind,cx,cy,cn] = windcoef(gamma_r,V_r,L,B,A_L,A_T,A_SS,S,C,M);
    wdata(i,:) = [gamma_r*180/pi w_wind'];
    i = i+1;
end

subplot(311)
plot(wdata(:,1),wdata(:,2),'b',wdata(:,1),wdata(:,2),'xk')

subplot(312)
plot(wdata(:,1),wdata(:,3),'b',wdata(:,1),wdata(:,3),'xk')

subplot(313)
plot(wdata(:,1),wdata(:,4),'b',wdata(:,1),wdata(:,4),'xk')

%%%%%%%%% CASE 2 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
V_r = 40;  % wind speed (m/s)
i = 1; 

for gamma_r = 0:0.1:pi,
    [w_wind,cx,cy,cn] = windcoef(gamma_r,V_r,L,B,A_L,A_T,A_SS,S,C,M);
    wdata(i,:) = [gamma_r*180/pi w_wind'];
    i = i+1;
end

subplot(311)
hold on
plot(wdata(:,1),wdata(:,2),'b',wdata(:,1),wdata(:,2),'ok');grid
title('X_{wind} (N)')
hold off

subplot(312)
hold on
plot(wdata(:,1),wdata(:,3),'b',wdata(:,1),wdata(:,3),'ok');grid
title('Y_{wind} (N)')
hold off

subplot(313)
hold on
plot(wdata(:,1),wdata(:,4),'b',wdata(:,1),wdata(:,4),'ok');grid
title('N_{wind} (Nm)')
xlabel('\gamma_r (deg)')
hold off