function [ret,x0,str,ts,xts]=phreg(t,x,u,flag);
%PHREG	is the M-file description of the SIMULINK system named PHREG.
%	The block-diagram can be displayed by typing: PHREG.
%
%	SYS=PHREG(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes PHREG to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling PHREG with a FLAG of zero:
%	[SIZES]=PHREG([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[664,426,1096,508])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Diskret reg'.

new_system([sys,'/','Diskret reg'])
set_param([sys,'/','Diskret reg'],'Location',[-20,1179795,1050,1180470])

add_block('built-in/Outport',[sys,'/','Diskret reg/out_1'])
set_param([sys,'/','Diskret reg/out_1'],...
		'position',[1025,315,1045,335])

add_block('built-in/Inport',[sys,'/','Diskret reg/in_2'])
set_param([sys,'/','Diskret reg/in_2'],...
		'Port','2',...
		'position',[50,200,70,220])

add_block('built-in/Inport',[sys,'/','Diskret reg/in_1'])
set_param([sys,'/','Diskret reg/in_1'],...
		'position',[115,110,135,130])

add_block('built-in/Filter',[sys,'/','Diskret reg/Derivator Tustin'])
set_param([sys,'/','Diskret reg/Derivator Tustin'],...
		'Numerator','[2*Td, -2*Td]',...
		'Denominator','[h+2*Td/N h-2*Td/N]',...
		'Sample time','h',...
		'position',[280,557,430,613])

add_block('built-in/Filter',[sys,'/','Diskret reg/Derivator Bakoverdiff'])
set_param([sys,'/','Diskret reg/Derivator Bakoverdiff'],...
		'Numerator','[Td, -Td]',...
		'Denominator','[h+Td/N -Td/N]',...
		'Sample time','h',...
		'position',[300,425,410,475])

add_block('built-in/Constant',[sys,'/','Diskret reg/Enkel (N-1000>=0)'])
set_param([sys,'/','Diskret reg/Enkel (N-1000>=0)'],...
		'Value','N-1000',...
		'position',[360,374,415,396])

add_block('built-in/Constant',[sys,'/',['Diskret reg/Bakoverdiff (type>=0)',13,' eller Tustin (type<0)']])
set_param([sys,'/',['Diskret reg/Bakoverdiff (type>=0)',13,' eller Tustin (type<0)']],...
		'Value','type',...
		'position',[320,494,375,516])

add_block('built-in/Switch',[sys,'/','Diskret reg/Tust//Bak'])
set_param([sys,'/','Diskret reg/Tust//Bak'],...
		'position',[460,489,485,521])

add_block('built-in/Switch',[sys,'/','Diskret reg/enkel//N'])
set_param([sys,'/','Diskret reg/enkel//N'],...
		'position',[515,369,540,401])

add_block('built-in/Filter',[sys,'/',['Diskret reg/Enkel diskret',13,'derivator']])
set_param([sys,'/',['Diskret reg/Enkel diskret',13,'derivator']],...
		'Numerator','[Td, -Td]',...
		'Denominator','[h]',...
		'Sample time','h',...
		'position',[395,302,495,348])

add_block('built-in/Filter',[sys,'/','Diskret reg/Forsinkelse'])
set_param([sys,'/','Diskret reg/Forsinkelse'],...
		'Numerator','[0 1]',...
		'Denominator','[1]',...
		'Sample time','h',...
		'position',[885,326,930,364])

add_block('built-in/Constant',[sys,'/',['Diskret reg/Rask (r>=0) eller',13,'langsom (r<0)',13,'regulator']])
set_param([sys,'/',['Diskret reg/Rask (r>=0) eller',13,'langsom (r<0)',13,'regulator']],...
		'Value','r',...
		'position',[890,220,910,240])

add_block('built-in/Constant',[sys,'/',['Diskret reg/Derivasjon av',13,'e (b>=0) eller',13,'y (<0)']])
set_param([sys,'/',['Diskret reg/Derivasjon av',13,'e (b>=0) eller',13,'y (<0)']],...
		'Value','b',...
		'position',[225,240,245,260])

add_block('built-in/Switch',[sys,'/','Diskret reg/Rask//langsom'])
set_param([sys,'/','Diskret reg/Rask//langsom'],...
		'position',[970,309,995,341])

add_block('built-in/Switch',[sys,'/','Diskret reg/e eller y'])
set_param([sys,'/','Diskret reg/e eller y'],...
		'position',[330,309,355,341])

add_block('built-in/Zero-Order Hold',[sys,'/',['Diskret reg/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Diskret reg/Zero-Order',13,'Hold1']],...
		'Sample time','h',...
		'position',[200,169,235,201])

add_block('built-in/Zero-Order Hold',[sys,'/',['Diskret reg/Zero-Order',13,'Hold']])
set_param([sys,'/',['Diskret reg/Zero-Order',13,'Hold']],...
		'Sample time','h',...
		'position',[190,104,225,136])

add_block('built-in/Filter',[sys,'/',['Diskret reg/Diskret',13,'Integrator']])
set_param([sys,'/',['Diskret reg/Diskret',13,'Integrator']],...
		'Numerator','[0 1]',...
		'Denominator','[1 -1]',...
		'Sample time','h',...
		'position',[520,136,565,174])

add_block('built-in/Constant',[sys,'/',['Diskret reg/Auto(ah=1)',13,'Hand(ah=0)']])
set_param([sys,'/',['Diskret reg/Auto(ah=1)',13,'Hand(ah=0)']],...
		'Value','ah',...
		'position',[365,214,410,236])


%     Subsystem  'Diskret reg/P//Av'.

new_system([sys,'/','Diskret reg/P//Av'])
set_param([sys,'/','Diskret reg/P//Av'],'Location',[640,638,1006,807])

add_block('built-in/Outport',[sys,'/','Diskret reg/P//Av/out_1'])
set_param([sys,'/','Diskret reg/P//Av/out_1'],...
		'position',[180,75,200,95])

add_block('built-in/Switch',[sys,'/','Diskret reg/P//Av/Switch2'])
set_param([sys,'/','Diskret reg/P//Av/Switch2'],...
		'Threshold','0.5',...
		'position',[125,69,150,101])

add_block('built-in/Inport',[sys,'/','Diskret reg/P//Av/in_1'])
set_param([sys,'/','Diskret reg/P//Av/in_1'],...
		'position',[50,30,70,50])

add_block('built-in/Inport',[sys,'/','Diskret reg/P//Av/in_2'])
set_param([sys,'/','Diskret reg/P//Av/in_2'],...
		'Port','2',...
		'position',[50,75,70,95])

add_block('built-in/Constant',[sys,'/','Diskret reg/P//Av/Null1'])
set_param([sys,'/','Diskret reg/P//Av/Null1'],...
		'Value','0',...
		'position',[50,122,85,138])
add_line([sys,'/','Diskret reg/P//Av'],[75,85;120,85])
add_line([sys,'/','Diskret reg/P//Av'],[155,85;175,85])
add_line([sys,'/','Diskret reg/P//Av'],[90,130;120,95])
add_line([sys,'/','Diskret reg/P//Av'],[75,40;95,60;120,75])


%     Finished composite block 'Diskret reg/P//Av'.

set_param([sys,'/','Diskret reg/P//Av'],...
		'position',[430,127,460,178])

add_block('built-in/Gain',[sys,'/','Diskret reg/h//Ti'])
set_param([sys,'/','Diskret reg/h//Ti'],...
		'Gain','(Ti<1000)/(Ti/h)',...
		'position',[475,145,495,165])


%     Subsystem  'Diskret reg/Anti windup'.

new_system([sys,'/','Diskret reg/Anti windup'])
set_param([sys,'/','Diskret reg/Anti windup'],'Location',[74,635,614,805])

add_block('built-in/Note',[sys,'/',['Diskret reg/Anti windup/Dersom in_1 er strre enn vre grense (ub) og in_2 er strre',13,'enn null s blir out_1 lik null, ellers blir out_1lik in_2',13,'Tilsvarende for nedre grense!']])
set_param([sys,'/',['Diskret reg/Anti windup/Dersom in_1 er strre enn vre grense (ub) og in_2 er strre',13,'enn null s blir out_1 lik null, ellers blir out_1lik in_2',13,'Tilsvarende for nedre grense!']],...
		'position',[310,16,315,21])

add_block('built-in/Inport',[sys,'/','Diskret reg/Anti windup/in_1'])
set_param([sys,'/','Diskret reg/Anti windup/in_1'],...
		'position',[35,55,55,75])

add_block('built-in/Inport',[sys,'/','Diskret reg/Anti windup/in_2'])
set_param([sys,'/','Diskret reg/Anti windup/in_2'],...
		'Port','2',...
		'position',[35,105,55,125])

add_block('built-in/Outport',[sys,'/','Diskret reg/Anti windup/out_1'])
set_param([sys,'/','Diskret reg/Anti windup/out_1'],...
		'position',[500,85,520,105])

add_block('built-in/Mux',[sys,'/','Diskret reg/Anti windup/Mux'])
set_param([sys,'/','Diskret reg/Anti windup/Mux'],...
		'inputs','2',...
		'position',[85,76,115,109])

add_block('built-in/Fcn',[sys,'/','Diskret reg/Anti windup/Fcn'])
set_param([sys,'/','Diskret reg/Anti windup/Fcn'],...
		'Expr','u[2]*((((u[1]>lb)+(u[2]*K>=0))>0) * (((u[1]<ub)+(u[2]*K<=0))>0))',...
		'position',[135,75,480,115])
add_line([sys,'/','Diskret reg/Anti windup'],[60,115;80,100])
add_line([sys,'/','Diskret reg/Anti windup'],[485,95;495,95])
add_line([sys,'/','Diskret reg/Anti windup'],[60,65;80,85])
add_line([sys,'/','Diskret reg/Anti windup'],[120,95;130,95])


%     Finished composite block 'Diskret reg/Anti windup'.

set_param([sys,'/','Diskret reg/Anti windup'],...
		'position',[375,127,405,178])


%     Subsystem  ['Diskret reg/Metning og ',13,'auto//hand'].

new_system([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']])
set_param([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],'Location',[237,50,852,425])

add_block('built-in/Inport',[sys,'/',['Diskret reg/Metning og ',13,'auto//hand/in_1']])
set_param([sys,'/',['Diskret reg/Metning og ',13,'auto//hand/in_1']],...
		'position',[25,170,45,190])

add_block('built-in/Constant',[sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Auto//Hand']])
set_param([sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Auto//Hand']],...
		'Value','ah',...
		'position',[95,254,140,276])

add_block('built-in/Switch',[sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Switch']])
set_param([sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Switch']],...
		'Threshold','0.5',...
		'position',[240,214,265,246])

add_block('built-in/Memory',[sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Memory1']])
set_param([sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Memory1']],...
		'position',[310,215,350,245])

add_block('built-in/Sum',[sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Sum2']])
set_param([sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Sum2']],...
		'position',[400,222,420,258])

add_block('built-in/Inport',[sys,'/',['Diskret reg/Metning og ',13,'auto//hand/in_2']])
set_param([sys,'/',['Diskret reg/Metning og ',13,'auto//hand/in_2']],...
		'Port','2',...
		'position',[25,295,45,315])

add_block('built-in/Switch',[sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Switch1']])
set_param([sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Switch1']],...
		'Threshold','0.5',...
		'position',[465,184,490,216])

add_block('built-in/Sum',[sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Sum1']])
set_param([sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Sum1']],...
		'position',[390,117,410,153])

add_block('built-in/Memory',[sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Memory2']])
set_param([sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Memory2']],...
		'position',[300,110,340,140])

add_block('built-in/Switch',[sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Switch2']])
set_param([sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Switch2']],...
		'Threshold','0.5',...
		'position',[230,109,255,141])

add_block('built-in/Saturation',[sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Metnings-',13,'grenser1']])
set_param([sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Metnings-',13,'grenser1']],...
		'Lower Limit','lb',...
		'Upper Limit','ub',...
		'position',[525,190,550,210])

add_block('built-in/Outport',[sys,'/',['Diskret reg/Metning og ',13,'auto//hand/out_2']])
set_param([sys,'/',['Diskret reg/Metning og ',13,'auto//hand/out_2']],...
		'Port','2',...
		'position',[580,190,600,210])

add_block('built-in/Outport',[sys,'/',['Diskret reg/Metning og ',13,'auto//hand/out_1']])
set_param([sys,'/',['Diskret reg/Metning og ',13,'auto//hand/out_1']],...
		'position',[490,125,510,145])

add_block('built-in/Sum',[sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Sum3']])
set_param([sys,'/',['Diskret reg/Metning og ',13,'auto//hand/Sum3']],...
		'inputs','+-',...
		'position',[140,117,160,153])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[555,200;555,70;100,70;100,220;235,220])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[50,305;385,305;395,250])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[555,200;575,200])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[145,265;175,265;175,230;235,230])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[355,230;395,230])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[270,230;305,230])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[355,230;370,230;370,280;210,280;210,240;235,240])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[425,240;460,210])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[260,125;295,125])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[345,125;385,125])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[415,135;430,135;430,190;460,190])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[345,125;355,125;355,90;210,90;210,115;225,115])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[495,200;520,200])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[145,265;175,265;175,200;460,200])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[50,180;365,180;385,145])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[145,265;175,265;175,125;225,125])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[415,135;485,135])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[50,180;120,180;120,145;135,145])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[555,200;555,70;100,70;100,125;135,125])
add_line([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],[165,135;225,135])


%     Finished composite block ['Diskret reg/Metning og ',13,'auto//hand'].

set_param([sys,'/',['Diskret reg/Metning og ',13,'auto//hand']],...
		'position',[815,302,845,353])

add_block('built-in/Constant',[sys,'/',['Diskret reg/Pdragsendring',13,'ved hand']])
set_param([sys,'/',['Diskret reg/Pdragsendring',13,'ved hand']],...
		'Value','dp',...
		'position',[725,349,770,371])

add_block('built-in/Note',[sys,'/','Diskret reg/e'])
set_param([sys,'/','Diskret reg/e'],...
		'position',[315,146,320,151])

add_block('built-in/Sum',[sys,'/','Diskret reg/error'])
set_param([sys,'/','Diskret reg/error'],...
		'inputs','+-',...
		'position',[275,147,295,183])

add_block('built-in/Gain',[sys,'/','Diskret reg/Proportional'])
set_param([sys,'/','Diskret reg/Proportional'],...
		'Gain','K',...
		'position',[625,299,675,331])

add_block('built-in/Sum',[sys,'/','Diskret reg/P+I+D'])
set_param([sys,'/','Diskret reg/P+I+D'],...
		'inputs','+++',...
		'position',[575,297,595,333])

add_block('built-in/Gain',[sys,'/','Diskret reg/Gain1'])
set_param([sys,'/','Diskret reg/Gain1'],...
		'Gain','-1',...
		'position',[220,325,240,345])

add_block('built-in/Constant',[sys,'/',['Diskret reg/Nominelt',13,'paadrag']])
set_param([sys,'/',['Diskret reg/Nominelt',13,'paadrag']],...
		'Value','zero',...
		'position',[605,355,650,375])

add_block('built-in/Sum',[sys,'/','Diskret reg/Sum3'])
set_param([sys,'/','Diskret reg/Sum3'],...
		'hide name',0,...
		'position',[700,297,720,333])

add_block('built-in/Note',[sys,'/','Diskret reg/r '])
set_param([sys,'/','Diskret reg/r '],...
		'position',[150,90,155,101])

add_block('built-in/Note',[sys,'/','Diskret reg/Diskret PID regulator anti-windup og metningsgrenser p utgangen samt nominelt pdrag.'])
set_param([sys,'/','Diskret reg/Diskret PID regulator anti-windup og metningsgrenser p utgangen samt nominelt pdrag.'],...
		'position',[390,71,395,76])

add_block('built-in/Gain',[sys,'/','Diskret reg/Gain'])
set_param([sys,'/','Diskret reg/Gain'],...
		'position',[130,200,150,220])

add_block('built-in/Note',[sys,'/','Diskret reg/y'])
set_param([sys,'/','Diskret reg/y'],...
		'position',[85,186,90,191])
add_line([sys,'/','Diskret reg'],[1000,325;1020,325])
add_line([sys,'/','Diskret reg'],[850,315;865,315;865,270;325,270;325,140;370,140])
add_line([sys,'/','Diskret reg'],[850,340;860,340;890,315;965,315])
add_line([sys,'/','Diskret reg'],[850,340;855,340;855,345;880,345])
add_line([sys,'/','Diskret reg'],[75,210;125,210])
add_line([sys,'/','Diskret reg'],[420,385;510,385])
add_line([sys,'/','Diskret reg'],[380,505;455,505])
add_line([sys,'/','Diskret reg'],[435,585;435,515;455,515])
add_line([sys,'/','Diskret reg'],[360,325;370,325;370,370;260,370;260,585;275,585])
add_line([sys,'/','Diskret reg'],[360,325;370,325;370,370;260,370;260,450;295,450])
add_line([sys,'/','Diskret reg'],[490,505;495,505;495,395;510,395])
add_line([sys,'/','Diskret reg'],[415,450;440,450;440,495;455,495])
add_line([sys,'/','Diskret reg'],[545,385;550,385;550,325;570,325])
add_line([sys,'/','Diskret reg'],[500,325;510,375])
add_line([sys,'/','Diskret reg'],[935,345;965,335])
add_line([sys,'/','Diskret reg'],[915,230;955,230;965,325])
add_line([sys,'/','Diskret reg'],[500,155;515,155])
add_line([sys,'/','Diskret reg'],[155,210;170,210;170,335;215,335])
add_line([sys,'/','Diskret reg'],[725,315;810,315])
add_line([sys,'/','Diskret reg'],[300,165;370,165])
add_line([sys,'/','Diskret reg'],[570,155;550,305;570,305])
add_line([sys,'/','Diskret reg'],[600,315;620,315])
add_line([sys,'/','Diskret reg'],[655,365;680,365;680,325;695,325])
add_line([sys,'/','Diskret reg'],[300,165;340,165;340,285;525,285;525,315;570,315])
add_line([sys,'/','Diskret reg'],[360,325;390,325])
add_line([sys,'/','Diskret reg'],[300,165;305,165;305,315;325,315])
add_line([sys,'/','Diskret reg'],[245,335;325,335])
add_line([sys,'/','Diskret reg'],[250,250;280,250;280,325;325,325])
add_line([sys,'/','Diskret reg'],[680,315;680,305;695,305])
add_line([sys,'/','Diskret reg'],[775,360;810,340])
add_line([sys,'/','Diskret reg'],[415,225;425,165])
add_line([sys,'/','Diskret reg'],[465,155;470,155])
add_line([sys,'/','Diskret reg'],[410,155;410,140;425,140])
add_line([sys,'/','Diskret reg'],[230,120;255,120;255,155;270,155])
add_line([sys,'/','Diskret reg'],[240,185;250,185;250,175;270,175])
add_line([sys,'/','Diskret reg'],[155,210;170,210;170,185;195,185])
add_line([sys,'/','Diskret reg'],[140,120;185,120])
set_param([sys,'/','Diskret reg'],...
		'Mask Display','plot(-8,-0.3,3,1.3,[0,1,2,3],[0,0,1,1]);phdPID   ',...
		'Mask Type','Diskret anti windup PID med auto/hand 9/4-96 P Hv')
set_param([sys,'/','Diskret reg'],...
		'Mask Dialogue','Setpoint PID with anti-windup: e=(r-y) P=K*e\nD=(KTds/(1+Td/Ns)* (e eller y)\nI=(K/Tis)*e|Kp|Ti   (Ti>=1000 kopler ut I-del)|[Td,N]   (N>=1000 gir ideell derivator)|[Sampl.tid, rask(0)/langsom(-1), bakover(0)/tustin(-1)]|Metningsgrenser og nom. pdrag [low,high,nomp]|[Derivasjon  av e (0)/av y (-1),Auto(1)/Hand(0),dPdrag]')
set_param([sys,'/','Diskret reg'],...
		'Mask Translate','K=@1 ; Ti=@2 ;Td=@3(1); N=@3(2); h=@4(1);r=@4(2);type=@4(3);lb=@5(1); ub=@5(2);  zero=@5(3) ;b=@6(1) ;ah=@6(2); dp=@6(3);  ')
set_param([sys,'/','Diskret reg'],...
		'Mask Help','Unmask this block to see how it works. Attach the set point to input 1, the system output to input 2, and the output of the block to the system''s input.')
set_param([sys,'/','Diskret reg'],...
		'Mask Entries','2\/1000\/[0,10]\/[0.1,0,0]\/[-10,10,0.5]\/[0,1,0.0]\/')


%     Finished composite block 'Diskret reg'.

set_param([sys,'/','Diskret reg'],...
		'position',[100,9,160,51])


%     Subsystem  ['P-reg',13,'m// pot'].

new_system([sys,'/',['P-reg',13,'m// pot']])
set_param([sys,'/',['P-reg',13,'m// pot']],'Location',[32,432,357,591])

add_block('built-in/Outport',[sys,'/',['P-reg',13,'m// pot/Til pdrag']])
set_param([sys,'/',['P-reg',13,'m// pot/Til pdrag']],...
		'position',[280,45,300,65])

add_block('built-in/Inport',[sys,'/',['P-reg',13,'m// pot/Fra',13,'REF']])
set_param([sys,'/',['P-reg',13,'m// pot/Fra',13,'REF']],...
		'position',[20,5,40,25])

add_block('built-in/Inport',[sys,'/',['P-reg',13,'m// pot/Fra PV']])
set_param([sys,'/',['P-reg',13,'m// pot/Fra PV']],...
		'Port','2',...
		'position',[20,95,40,115])

add_block('built-in/Sum',[sys,'/',['P-reg',13,'m// pot/Sum']])
set_param([sys,'/',['P-reg',13,'m// pot/Sum']],...
		'inputs','+-',...
		'position',[60,40,80,60])

add_block('built-in/Gain',[sys,'/',['P-reg',13,'m// pot/Kp']])
set_param([sys,'/',['P-reg',13,'m// pot/Kp']],...
		'Mask Display','1',...
		'Mask Dialogue','eval(''slideg(0,1,10,0)'');',...
		'position',[95,36,145,64])

add_block('built-in/Sum',[sys,'/',['P-reg',13,'m// pot/Sum1']])
set_param([sys,'/',['P-reg',13,'m// pot/Sum1']],...
		'position',[170,45,190,65])

add_block('built-in/Saturation',[sys,'/',['P-reg',13,'m// pot/Metnings-',13,'grenser']])
set_param([sys,'/',['P-reg',13,'m// pot/Metnings-',13,'grenser']],...
		'Lower Limit','0',...
		'Upper Limit','1',...
		'position',[220,45,245,65])

add_block('built-in/Note',[sys,'/',['P-reg',13,'m// pot/Dobbeltklikk i Kp-blokk']])
set_param([sys,'/',['P-reg',13,'m// pot/Dobbeltklikk i Kp-blokk']],...
		'position',[140,5,145,10])

add_block('built-in/Constant',[sys,'/',['P-reg',13,'m// pot/Nominelt pdrag']])
set_param([sys,'/',['P-reg',13,'m// pot/Nominelt pdrag']],...
		'Value','0.5',...
		'position',[95,119,140,141])
add_line([sys,'/',['P-reg',13,'m// pot']],[195,55;215,55])
add_line([sys,'/',['P-reg',13,'m// pot']],[145,130;155,130;165,60])
add_line([sys,'/',['P-reg',13,'m// pot']],[150,50;165,50])
add_line([sys,'/',['P-reg',13,'m// pot']],[85,50;90,50])
add_line([sys,'/',['P-reg',13,'m// pot']],[45,15;55,45])
add_line([sys,'/',['P-reg',13,'m// pot']],[250,55;275,55])
add_line([sys,'/',['P-reg',13,'m// pot']],[45,105;55,55])


%     Finished composite block ['P-reg',13,'m// pot'].

set_param([sys,'/',['P-reg',13,'m// pot']],...
		'position',[185,9,245,51])


%     Subsystem  ['P-reg med',13,'auto//hand'].

new_system([sys,'/',['P-reg med',13,'auto//hand']])
set_param([sys,'/',['P-reg med',13,'auto//hand']],'Location',[547,149,1013,331])

add_block('built-in/Outport',[sys,'/',['P-reg med',13,'auto//hand/out_1']])
set_param([sys,'/',['P-reg med',13,'auto//hand/out_1']],...
		'position',[425,95,445,115])

add_block('built-in/Constant',[sys,'/',['P-reg med',13,'auto//hand/Pdragsendring',13,'ved hand']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Pdragsendring',13,'ved hand']],...
		'Value','dp',...
		'position',[245,124,290,146])


%     Subsystem  ['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand'].

new_system([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],'Location',[539,59,1178,440])

add_block('built-in/Memory',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Memory1']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Memory1']],...
		'position',[310,215,350,245])

add_block('built-in/Switch',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Switch']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Switch']],...
		'Threshold','0.5',...
		'position',[240,214,265,246])

add_block('built-in/Inport',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/in_2']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/in_2']],...
		'Port','2',...
		'position',[335,335,355,355])

add_block('built-in/Outport',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/out_1']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/out_1']],...
		'position',[605,210,625,230])

add_block('built-in/Inport',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/in_1']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/in_1']],...
		'position',[15,15,35,35])


%     Subsystem  ['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1'].

new_system([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1']],'Location',[265,461,613,646])

add_block('built-in/Constant',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1/Null2']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1/Null2']],...
		'Value','0',...
		'position',[125,37,160,53])

add_block('built-in/Inport',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1/in_1']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1/in_1']],...
		'position',[120,85,140,105])

add_block('built-in/Outport',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1/out_1']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1/out_1']],...
		'position',[255,85,275,105])

add_block('built-in/Switch',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1/Switch3']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1/Switch3']],...
		'Threshold','0.5',...
		'position',[190,79,215,111])

add_block('built-in/Inport',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1/in_2']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1/in_2']],...
		'Port','2',...
		'position',[130,130,150,150])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1']],[145,95;185,95])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1']],[220,95;250,95])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1']],[165,45;185,85])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1']],[155,140;165,140;165,105;185,105])


%     Finished composite block ['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1'].

set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P1']],...
		'position',[405,192,435,243])


%     Subsystem  ['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av'].

new_system([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av']],'Location',[215,257,581,426])

add_block('built-in/Outport',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av/out_1']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av/out_1']],...
		'position',[180,75,200,95])

add_block('built-in/Switch',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av/Switch2']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av/Switch2']],...
		'Threshold','0.5',...
		'position',[125,69,150,101])

add_block('built-in/Inport',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av/in_1']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av/in_1']],...
		'position',[50,30,70,50])

add_block('built-in/Inport',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av/in_2']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av/in_2']],...
		'Port','2',...
		'position',[50,75,70,95])

add_block('built-in/Constant',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av/Null1']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av/Null1']],...
		'Value','0',...
		'position',[50,122,85,138])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av']],[75,85;120,85])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av']],[155,85;175,85])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av']],[90,130;120,95])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av']],[75,40;95,60;120,75])


%     Finished composite block ['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av'].

set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/P//Av']],...
		'position',[370,107,400,158])


%     Subsystem  ['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P'].

new_system([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P']],'Location',[265,461,568,686])

add_block('built-in/Inport',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P/in_2']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P/in_2']],...
		'Port','2',...
		'position',[120,120,140,140])

add_block('built-in/Inport',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P/in_1']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P/in_1']],...
		'position',[100,85,120,105])

add_block('built-in/Constant',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P/Null2']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P/Null2']],...
		'Value','0',...
		'position',[110,52,145,68])

add_block('built-in/Switch',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P/Switch3']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P/Switch3']],...
		'Threshold','0.5',...
		'position',[190,79,215,111])

add_block('built-in/Outport',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P/out_1']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P/out_1']],...
		'position',[245,85,265,105])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P']],[145,130;160,130;160,105;185,105])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P']],[125,95;185,95])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P']],[150,60;160,60;160,85;185,85])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P']],[220,95;240,95])


%     Finished composite block ['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P'].

set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Av//P']],...
		'position',[385,307,415,358])

add_block('built-in/Saturation',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Metnings-',13,'grenser1']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Metnings-',13,'grenser1']],...
		'Lower Limit','lb',...
		'Upper Limit','ub',...
		'position',[550,210,575,230])

add_block('built-in/Sum',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Sum2']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Sum2']],...
		'inputs','+++',...
		'position',[490,202,510,238])

add_block('built-in/Constant',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Auto//Hand']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Auto//Hand']],...
		'Value','ah',...
		'position',[95,254,140,276])

add_block('built-in/Saturation',[sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Metnings-',13,'grenser']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand/Metnings-',13,'grenser']],...
		'Lower Limit','lb',...
		'Upper Limit','ub',...
		'position',[100,10,120,40])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],[355,230;370,230;370,280;210,280;210,240;235,240])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],[270,230;305,230])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],[355,230;400,230])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],[145,265;175,265;175,230;235,230])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],[145,265;175,265;175,320;380,320])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],[145,265;175,265;175,145;335,145;335,205;400,205])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],[145,265;175,265;175,145;365,145])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],[125,25;145,25;145,220;235,220])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],[125,25;145,25;145,120;365,120])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],[515,220;545,220])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],[420,335;455,335;455,230;485,230])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],[405,135;455,135;455,210;485,210])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],[440,220;485,220])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],[40,25;95,25])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],[580,220;600,220])
add_line([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],[360,345;380,345])


%     Finished composite block ['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand'].

set_param([sys,'/',['P-reg med',13,'auto//hand/Metning og ',13,'auto//hand']],...
		'position',[335,77,365,128])

add_block('built-in/Gain',[sys,'/',['P-reg med',13,'auto//hand/Kp']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Kp']],...
		'Gain','kp',...
		'position',[135,75,155,95])

add_block('built-in/Constant',[sys,'/',['P-reg med',13,'auto//hand/Nominelt pdrag']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Nominelt pdrag']],...
		'Value','zero',...
		'position',[125,129,170,151])

add_block('built-in/Sum',[sys,'/',['P-reg med',13,'auto//hand/Sum']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Sum']],...
		'inputs','+-',...
		'position',[90,75,110,95])

add_block('built-in/Sum',[sys,'/',['P-reg med',13,'auto//hand/Sum1']])
set_param([sys,'/',['P-reg med',13,'auto//hand/Sum1']],...
		'position',[200,80,220,100])

add_block('built-in/Inport',[sys,'/',['P-reg med',13,'auto//hand/in_2']])
set_param([sys,'/',['P-reg med',13,'auto//hand/in_2']],...
		'Port','2',...
		'position',[40,100,60,120])

add_block('built-in/Inport',[sys,'/',['P-reg med',13,'auto//hand/in_1']])
set_param([sys,'/',['P-reg med',13,'auto//hand/in_1']],...
		'position',[40,60,60,80])
add_line([sys,'/',['P-reg med',13,'auto//hand']],[295,135;330,115])
add_line([sys,'/',['P-reg med',13,'auto//hand']],[225,90;330,90])
add_line([sys,'/',['P-reg med',13,'auto//hand']],[175,140;185,140;195,95])
add_line([sys,'/',['P-reg med',13,'auto//hand']],[160,85;195,85])
add_line([sys,'/',['P-reg med',13,'auto//hand']],[115,85;130,85])
add_line([sys,'/',['P-reg med',13,'auto//hand']],[65,70;85,80])
add_line([sys,'/',['P-reg med',13,'auto//hand']],[65,110;85,90])
add_line([sys,'/',['P-reg med',13,'auto//hand']],[370,105;420,105])
set_param([sys,'/',['P-reg med',13,'auto//hand']],...
		'Mask Display','plot(-4,-0.3,4,1.3,[0,1,2,3],[0,0,1,1]);   phP     ',...
		'Mask Type','Auto/hand P-reg')
set_param([sys,'/',['P-reg med',13,'auto//hand']],...
		'Mask Dialogue','P-reg med mulighet fra auto/hand|Auto=1 Hand (manuell)=0|P-forsterking:|Nominelt pdrag (Nullpunktforskyving)|Metningsgrenser [low,high]|Endring i pdrag ved hand')
set_param([sys,'/',['P-reg med',13,'auto//hand']],...
		'Mask Translate','ah=@1 ; kp=@2; zero =@3 ; lb=@4(1); ub=@4(2); dp=@5;')
set_param([sys,'/',['P-reg med',13,'auto//hand']],...
		'Mask Help','Unmask this block to see how it works. Attach the set point to input 1, the system output to input 2, and the output of the block to the system''s input.')
set_param([sys,'/',['P-reg med',13,'auto//hand']],...
		'Mask Entries','1\/1\/0.1\/[0,1]\/0.1\/')


%     Finished composite block ['P-reg med',13,'auto//hand'].

set_param([sys,'/',['P-reg med',13,'auto//hand']],...
		'position',[270,10,330,50])


%     Subsystem  'SeriePID'.

new_system([sys,'/','SeriePID'])
set_param([sys,'/','SeriePID'],'Location',[-25,35455067,520,35455407])

add_block('built-in/Switch',[sys,'/','SeriePID/PI eller PID'])
set_param([sys,'/','SeriePID/PI eller PID'],...
		'Threshold','1000',...
		'position',[350,129,375,161])

add_block('built-in/Sum',[sys,'/','SeriePID/Avvik'])
set_param([sys,'/','SeriePID/Avvik'],...
		'inputs','+-',...
		'position',[80,135,100,155])

add_block('built-in/Constant',[sys,'/','SeriePID/Bryterstyring'])
set_param([sys,'/','SeriePID/Bryterstyring'],...
		'Value','Ti',...
		'position',[195,130,255,160])

add_block('built-in/Transfer Fcn',[sys,'/','SeriePID/PID-serieregulator'])
set_param([sys,'/','SeriePID/PID-serieregulator'],...
		'Numerator','Kp*[Ti*Td, Ti+Td, 1]',...
		'Denominator','Ti*[Td/N, 1, 0]',...
		'position',[135,187,295,243])

add_block('built-in/Transfer Fcn',[sys,'/','SeriePID/PD-serieregulator'])
set_param([sys,'/','SeriePID/PD-serieregulator'],...
		'Numerator','Kp*[Td, 1]',...
		'Denominator','[Td/N 1]',...
		'position',[215,57,310,103])

add_block('built-in/Constant',[sys,'/',['SeriePID/Nominelt',13,'paadrag']])
set_param([sys,'/',['SeriePID/Nominelt',13,'paadrag']],...
		'Value','zero',...
		'position',[360,260,405,280])

add_block('built-in/Sum',[sys,'/','SeriePID/Sum3'])
set_param([sys,'/','SeriePID/Sum3'],...
		'hide name',0,...
		'position',[430,182,450,218])

add_block('built-in/Saturation',[sys,'/','SeriePID/Metning'])
set_param([sys,'/','SeriePID/Metning'],...
		'Lower Limit','lb',...
		'Upper Limit','ub',...
		'position',[475,190,500,210])

add_block('built-in/Inport',[sys,'/','SeriePID/in_1'])
set_param([sys,'/','SeriePID/in_1'],...
		'position',[30,130,45,150])

add_block('built-in/Inport',[sys,'/','SeriePID/in_2'])
set_param([sys,'/','SeriePID/in_2'],...
		'Port','2',...
		'position',[30,140,45,160])

add_block('built-in/Outport',[sys,'/','SeriePID/out_1'])
set_param([sys,'/','SeriePID/out_1'],...
		'position',[530,190,550,210])
add_line([sys,'/','SeriePID'],[380,145;400,145;400,190;425,190])
add_line([sys,'/','SeriePID'],[105,145;110,145;110,215;130,215])
add_line([sys,'/','SeriePID'],[105,145;150,145;150,80;210,80])
add_line([sys,'/','SeriePID'],[260,145;345,145])
add_line([sys,'/','SeriePID'],[300,215;320,215;320,155;345,155])
add_line([sys,'/','SeriePID'],[315,80;330,80;330,135;345,135])
add_line([sys,'/','SeriePID'],[410,270;415,270;425,210])
add_line([sys,'/','SeriePID'],[455,200;470,200])
add_line([sys,'/','SeriePID'],[50,140;75,140])
add_line([sys,'/','SeriePID'],[50,150;75,150])
add_line([sys,'/','SeriePID'],[505,200;525,200])
set_param([sys,'/','SeriePID'],...
		'Mask Display','     phSeriePID     ',...
		'Mask Type','Serie PID')
set_param([sys,'/','SeriePID'],...
		'Mask Dialogue','Serie PID : e=(r-y) P=K*e\n D=(KTds/(1+Td/Ns)*(e) \nI=(K/Tis)*e|Gain K|Ti (Ti>=1000 kopler ut I-delen)|Td|maks D-forsterking: N|Metningsgrenser [low,high]|Nominelt pdrag')
set_param([sys,'/','SeriePID'],...
		'Mask Translate','Kp=@1 ; Ti =@2 ; Td=@3 ; N=@4; lb=@5(1); ub=@5(2);zero=@6;')
set_param([sys,'/','SeriePID'],...
		'Mask Help','Unmask this block to see how it works. Attach the set point to input 1, the system output to input 2, and the output of the block to the system''s input.')
set_param([sys,'/','SeriePID'],...
		'Mask Entries','2\/100\/10\/10\/[-inf,inf]\/0.5\/')


%     Finished composite block 'SeriePID'.

set_param([sys,'/','SeriePID'],...
		'position',[345,8,415,57])


%     Subsystem  'Analog reg'.

new_system([sys,'/','Analog reg'])
set_param([sys,'/','Analog reg'],'Location',[19,49,846,489])

add_block('built-in/Sum',[sys,'/','Analog reg/Sum3'])
set_param([sys,'/','Analog reg/Sum3'],...
		'hide name',0,...
		'position',[610,232,630,268])

add_block('built-in/Constant',[sys,'/',['Analog reg/Nominelt',13,'paadrag']])
set_param([sys,'/',['Analog reg/Nominelt',13,'paadrag']],...
		'Value','zero',...
		'position',[515,290,560,310])

add_block('built-in/Note',[sys,'/','Analog reg/PID regulator anti-windup og metningsgrenser p utgangen samt nominelt pdrag.'])
set_param([sys,'/','Analog reg/PID regulator anti-windup og metningsgrenser p utgangen samt nominelt pdrag.'],...
		'position',[300,6,305,11])

add_block('built-in/Constant',[sys,'/','Analog reg/Bryterstyring'])
set_param([sys,'/','Analog reg/Bryterstyring'],...
		'Value','b',...
		'position',[135,200,155,220])

add_block('built-in/Gain',[sys,'/','Analog reg/Gain1'])
set_param([sys,'/','Analog reg/Gain1'],...
		'Gain','-1',...
		'position',[130,260,150,280])

add_block('built-in/Switch',[sys,'/','Analog reg/e eller y'])
set_param([sys,'/','Analog reg/e eller y'],...
		'position',[240,244,265,276])

add_block('built-in/Transfer Fcn',[sys,'/','Analog reg/Derivative'])
set_param([sys,'/','Analog reg/Derivative'],...
		'Numerator','[Td, 0]',...
		'Denominator','[Td/N 1]',...
		'position',[290,237,385,283])

add_block('built-in/Sum',[sys,'/','Analog reg/P+I+D'])
set_param([sys,'/','Analog reg/P+I+D'],...
		'inputs','+++',...
		'position',[485,232,505,268])

add_block('built-in/Gain',[sys,'/','Analog reg/Proportional'])
set_param([sys,'/','Analog reg/Proportional'],...
		'Gain','K',...
		'position',[535,234,585,266])

add_block('built-in/Note',[sys,'/','Analog reg/y'])
set_param([sys,'/','Analog reg/y'],...
		'position',[60,121,65,126])

add_block('built-in/Sum',[sys,'/','Analog reg/error'])
set_param([sys,'/','Analog reg/error'],...
		'inputs','+-',...
		'position',[185,82,205,118])

add_block('built-in/Note',[sys,'/','Analog reg/e'])
set_param([sys,'/','Analog reg/e'],...
		'position',[225,81,230,86])

add_block('built-in/Note',[sys,'/','Analog reg/r '])
set_param([sys,'/','Analog reg/r '],...
		'position',[65,66,70,71])

add_block('built-in/Inport',[sys,'/','Analog reg/Fra PV'])
set_param([sys,'/','Analog reg/Fra PV'],...
		'Port','2',...
		'position',[25,135,45,155])

add_block('built-in/Inport',[sys,'/','Analog reg/Fra ref'])
set_param([sys,'/','Analog reg/Fra ref'],...
		'position',[25,80,45,100])

add_block('built-in/Integrator',[sys,'/','Analog reg/Integrator'])
set_param([sys,'/','Analog reg/Integrator'],...
		'position',[425,80,445,100])

add_block('built-in/Constant',[sys,'/',['Analog reg/Pdragsendring',13,'ved hand']])
set_param([sys,'/',['Analog reg/Pdragsendring',13,'ved hand']],...
		'Value','dp',...
		'position',[635,284,680,306])


%     Subsystem  ['Analog reg/Metning og ',13,'auto//hand'].

new_system([sys,'/',['Analog reg/Metning og ',13,'auto//hand']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],'Location',[493,59,1132,440])

add_block('built-in/Saturation',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/Metnings-',13,'grenser']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Metnings-',13,'grenser']],...
		'Lower Limit','lb',...
		'Upper Limit','ub',...
		'position',[100,10,120,40])

add_block('built-in/Constant',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/Auto//Hand']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Auto//Hand']],...
		'Value','ah',...
		'position',[95,254,140,276])

add_block('built-in/Sum',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/Sum2']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Sum2']],...
		'inputs','+++',...
		'position',[490,202,510,238])

add_block('built-in/Saturation',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/Metnings-',13,'grenser1']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Metnings-',13,'grenser1']],...
		'Lower Limit','lb',...
		'Upper Limit','ub',...
		'position',[550,210,575,230])


%     Subsystem  ['Analog reg/Metning og ',13,'auto//hand/Av//P'].

new_system([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P']],'Location',[265,461,568,686])

add_block('built-in/Outport',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P/out_1']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P/out_1']],...
		'position',[245,85,265,105])

add_block('built-in/Switch',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P/Switch3']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P/Switch3']],...
		'Threshold','0.5',...
		'position',[190,79,215,111])

add_block('built-in/Constant',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P/Null2']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P/Null2']],...
		'Value','0',...
		'position',[110,52,145,68])

add_block('built-in/Inport',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P/in_1']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P/in_1']],...
		'position',[100,85,120,105])

add_block('built-in/Inport',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P/in_2']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P/in_2']],...
		'Port','2',...
		'position',[120,120,140,140])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P']],[220,95;240,95])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P']],[150,60;160,60;160,85;185,85])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P']],[125,95;185,95])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P']],[145,130;160,130;160,105;185,105])


%     Finished composite block ['Analog reg/Metning og ',13,'auto//hand/Av//P'].

set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P']],...
		'position',[385,307,415,358])


%     Subsystem  ['Analog reg/Metning og ',13,'auto//hand/P//Av'].

new_system([sys,'/',['Analog reg/Metning og ',13,'auto//hand/P//Av']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/P//Av']],'Location',[215,257,581,426])

add_block('built-in/Constant',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/P//Av/Null1']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/P//Av/Null1']],...
		'Value','0',...
		'position',[50,122,85,138])

add_block('built-in/Inport',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/P//Av/in_2']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/P//Av/in_2']],...
		'Port','2',...
		'position',[50,75,70,95])

add_block('built-in/Inport',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/P//Av/in_1']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/P//Av/in_1']],...
		'position',[50,30,70,50])

add_block('built-in/Switch',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/P//Av/Switch2']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/P//Av/Switch2']],...
		'Threshold','0.5',...
		'position',[125,69,150,101])

add_block('built-in/Outport',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/P//Av/out_1']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/P//Av/out_1']],...
		'position',[180,75,200,95])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand/P//Av']],[75,40;95,60;120,75])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand/P//Av']],[90,130;120,95])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand/P//Av']],[155,85;175,85])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand/P//Av']],[75,85;120,85])


%     Finished composite block ['Analog reg/Metning og ',13,'auto//hand/P//Av'].

set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/P//Av']],...
		'position',[370,107,400,158])


%     Subsystem  ['Analog reg/Metning og ',13,'auto//hand/Av//P1'].

new_system([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P1']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P1']],'Location',[265,461,613,646])

add_block('built-in/Inport',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P1/in_2']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P1/in_2']],...
		'Port','2',...
		'position',[130,130,150,150])

add_block('built-in/Switch',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P1/Switch3']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P1/Switch3']],...
		'Threshold','0.5',...
		'position',[190,79,215,111])

add_block('built-in/Outport',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P1/out_1']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P1/out_1']],...
		'position',[255,85,275,105])

add_block('built-in/Inport',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P1/in_1']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P1/in_1']],...
		'position',[120,85,140,105])

add_block('built-in/Constant',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P1/Null2']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P1/Null2']],...
		'Value','0',...
		'position',[125,37,160,53])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P1']],[155,140;165,140;165,105;185,105])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P1']],[165,45;185,85])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P1']],[220,95;250,95])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P1']],[145,95;185,95])


%     Finished composite block ['Analog reg/Metning og ',13,'auto//hand/Av//P1'].

set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Av//P1']],...
		'position',[405,192,435,243])

add_block('built-in/Inport',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/in_1']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/in_1']],...
		'position',[15,15,35,35])

add_block('built-in/Outport',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/out_1']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/out_1']],...
		'position',[605,210,625,230])

add_block('built-in/Inport',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/in_2']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/in_2']],...
		'Port','2',...
		'position',[335,335,355,355])

add_block('built-in/Switch',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/Switch']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Switch']],...
		'Threshold','0.5',...
		'position',[240,214,265,246])

add_block('built-in/Memory',[sys,'/',['Analog reg/Metning og ',13,'auto//hand/Memory1']])
set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand/Memory1']],...
		'position',[310,215,350,245])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],[360,345;380,345])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],[580,220;600,220])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],[40,25;95,25])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],[440,220;485,220])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],[405,135;455,135;455,210;485,210])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],[420,335;455,335;455,230;485,230])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],[515,220;545,220])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],[125,25;145,25;145,120;365,120])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],[125,25;145,25;145,220;235,220])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],[145,265;175,265;175,145;365,145])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],[145,265;175,265;175,145;335,145;335,205;400,205])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],[145,265;175,265;175,320;380,320])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],[145,265;175,265;175,230;235,230])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],[355,230;400,230])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],[270,230;305,230])
add_line([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],[355,230;370,230;370,280;210,280;210,240;235,240])


%     Finished composite block ['Analog reg/Metning og ',13,'auto//hand'].

set_param([sys,'/',['Analog reg/Metning og ',13,'auto//hand']],...
		'position',[725,237,755,288])


%     Subsystem  'Analog reg/Anti windup'.

new_system([sys,'/','Analog reg/Anti windup'])
set_param([sys,'/','Analog reg/Anti windup'],'Location',[150,123,690,293])

add_block('built-in/Note',[sys,'/',['Analog reg/Anti windup/Dersom in_1 er strre enn vre grense (ub) og in_2 er strre',13,'enn null s blir out_1 lik null, ellers blir out_1lik in_2',13,'Tilsvarende for nedre grense!']])
set_param([sys,'/',['Analog reg/Anti windup/Dersom in_1 er strre enn vre grense (ub) og in_2 er strre',13,'enn null s blir out_1 lik null, ellers blir out_1lik in_2',13,'Tilsvarende for nedre grense!']],...
		'position',[310,16,315,21])

add_block('built-in/Inport',[sys,'/','Analog reg/Anti windup/in_1'])
set_param([sys,'/','Analog reg/Anti windup/in_1'],...
		'position',[35,55,55,75])

add_block('built-in/Inport',[sys,'/','Analog reg/Anti windup/in_2'])
set_param([sys,'/','Analog reg/Anti windup/in_2'],...
		'Port','2',...
		'position',[35,105,55,125])

add_block('built-in/Outport',[sys,'/','Analog reg/Anti windup/out_1'])
set_param([sys,'/','Analog reg/Anti windup/out_1'],...
		'position',[500,85,520,105])

add_block('built-in/Mux',[sys,'/','Analog reg/Anti windup/Mux'])
set_param([sys,'/','Analog reg/Anti windup/Mux'],...
		'inputs','2',...
		'position',[85,76,115,109])

add_block('built-in/Fcn',[sys,'/','Analog reg/Anti windup/Fcn'])
set_param([sys,'/','Analog reg/Anti windup/Fcn'],...
		'Expr','u[2]*((((u[1]>lb)+(u[2]*K>=0))>0) * (((u[1]<ub)+(u[2]*K<=0))>0))',...
		'position',[135,75,480,115])
add_line([sys,'/','Analog reg/Anti windup'],[60,115;80,100])
add_line([sys,'/','Analog reg/Anti windup'],[485,95;495,95])
add_line([sys,'/','Analog reg/Anti windup'],[60,65;80,85])
add_line([sys,'/','Analog reg/Anti windup'],[120,95;130,95])


%     Finished composite block 'Analog reg/Anti windup'.

set_param([sys,'/','Analog reg/Anti windup'],...
		'position',[285,62,315,113])

add_block('built-in/Gain',[sys,'/','Analog reg/1//Ti'])
set_param([sys,'/','Analog reg/1//Ti'],...
		'Gain','(Ti<1000)/Ti',...
		'position',[385,80,405,100])


%     Subsystem  'Analog reg/P//Av'.

new_system([sys,'/','Analog reg/P//Av'])
set_param([sys,'/','Analog reg/P//Av'],'Location',[215,257,581,426])

add_block('built-in/Outport',[sys,'/','Analog reg/P//Av/out_1'])
set_param([sys,'/','Analog reg/P//Av/out_1'],...
		'position',[180,75,200,95])

add_block('built-in/Switch',[sys,'/','Analog reg/P//Av/Switch2'])
set_param([sys,'/','Analog reg/P//Av/Switch2'],...
		'Threshold','0.5',...
		'position',[125,69,150,101])

add_block('built-in/Inport',[sys,'/','Analog reg/P//Av/in_1'])
set_param([sys,'/','Analog reg/P//Av/in_1'],...
		'position',[50,30,70,50])

add_block('built-in/Inport',[sys,'/','Analog reg/P//Av/in_2'])
set_param([sys,'/','Analog reg/P//Av/in_2'],...
		'Port','2',...
		'position',[50,75,70,95])

add_block('built-in/Constant',[sys,'/','Analog reg/P//Av/Null1'])
set_param([sys,'/','Analog reg/P//Av/Null1'],...
		'Value','0',...
		'position',[50,122,85,138])
add_line([sys,'/','Analog reg/P//Av'],[75,85;120,85])
add_line([sys,'/','Analog reg/P//Av'],[155,85;175,85])
add_line([sys,'/','Analog reg/P//Av'],[90,130;120,95])
add_line([sys,'/','Analog reg/P//Av'],[75,40;95,60;120,75])


%     Finished composite block 'Analog reg/P//Av'.

set_param([sys,'/','Analog reg/P//Av'],...
		'position',[340,62,370,113])

add_block('built-in/Constant',[sys,'/','Analog reg/Auto//Hand'])
set_param([sys,'/','Analog reg/Auto//Hand'],...
		'Value','ah',...
		'position',[275,149,320,171])

add_block('built-in/Outport',[sys,'/',['Analog reg/Til',13,'pdrag']])
set_param([sys,'/',['Analog reg/Til',13,'pdrag']],...
		'position',[790,230,810,250])
add_line([sys,'/','Analog reg'],[410,90;420,90])
add_line([sys,'/','Analog reg'],[50,90;180,90])
add_line([sys,'/','Analog reg'],[50,145;110,145;110,110;180,110])
add_line([sys,'/','Analog reg'],[50,145;80,145;80,270;125,270])
add_line([sys,'/','Analog reg'],[760,265;785,240])
add_line([sys,'/','Analog reg'],[635,250;645,250;645,200;260,200;260,75;280,75])
add_line([sys,'/','Analog reg'],[635,250;720,250])
add_line([sys,'/','Analog reg'],[210,100;280,100])
add_line([sys,'/','Analog reg'],[450,90;460,90;460,240;480,240])
add_line([sys,'/','Analog reg'],[510,250;530,250])
add_line([sys,'/','Analog reg'],[390,260;480,260])
add_line([sys,'/','Analog reg'],[565,300;590,300;590,260;605,260])
add_line([sys,'/','Analog reg'],[210,100;250,100;250,220;435,220;435,250;480,250])
add_line([sys,'/','Analog reg'],[270,260;285,260])
add_line([sys,'/','Analog reg'],[210,100;215,100;215,250;235,250])
add_line([sys,'/','Analog reg'],[155,270;235,270])
add_line([sys,'/','Analog reg'],[160,210;190,210;190,260;235,260])
add_line([sys,'/','Analog reg'],[590,250;590,240;605,240])
add_line([sys,'/','Analog reg'],[685,295;720,275])
add_line([sys,'/','Analog reg'],[325,160;335,100])
add_line([sys,'/','Analog reg'],[375,90;380,90])
add_line([sys,'/','Analog reg'],[320,90;320,75;335,75])
set_param([sys,'/','Analog reg'],...
		'Mask Display','plot(-7,-0.3,4,1.3,[0,1,2,3],[0,0,1,1]);  phPID    ',...
		'Mask Type','Anti windup PID med auto/hand 18/10-96')
set_param([sys,'/','Analog reg'],...
		'Mask Dialogue','Setpoint PID with anti-windup: e=(r-y) P=K*e\nD=(KTds/(1+Td/Ns)* (e eller y)\nI=(K/Tis)*e|Gain K|Integral Ti (Ti>=1000 kopler ut I-del)|Derivasjonstid og max D-forsterking [Td,N]|[Nominelt pdrag,Auto=1/Hand=0,Pdragsendring]|Metningsgrenser [low,high]|Derivasjon av - e [0]/ av y [-1]')
set_param([sys,'/','Analog reg'],...
		'Mask Translate','K=@1 ; b =@6 ; Ti=@2 ; zero=@4(1) ;ah=@4(2); dp=@4(3); lb=@5(1); ub=@5(2); Td=@3(1); N=@3(2); ')
set_param([sys,'/','Analog reg'],...
		'Mask Help','Unmask this block to see how it works. Attach the set point to input 1, the system output to input 2, and the output of the block to the system''s input.')
set_param([sys,'/','Analog reg'],...
		'Mask Entries','1\/1000\/[0,10]\/[0.5,1,0.0]\/[0,1]\/0\/')


%     Finished composite block 'Analog reg'.

set_param([sys,'/','Analog reg'],...
		'position',[20,10,80,50])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
