function [z,p,k] = phtf2zp(num,den)

%phTF2ZP bygger p TF2ZP, men stripper imaginrdelen 
%for sammenfallende poler p reell akse eller like ved dersom
%zeta er mellom 0.999 og 1.0.  Per Hveem HIST 5/10-95
%
%  Se ogs TF2ZP, ZP2TF samt
% phLINMOD, phROOTS, phDAMP, phDDAMP, phPADE, phBODE, phDBODE


%TF2ZP	Transfer function to zero-pole conversion.
%	[Z,p,k] = TF2ZP(NUM,den)  finds the zeros, poles, and gains:
%
%		          (s-z1)(s-z2)...(s-zn)
%		H(s) =  K ---------------------
%		          (s-p1)(s-p2)...(s-pn)
%
%	from a SIMO transfer function in polynomial form:
%
%		        NUM(s)
%		H(s) = -------- 
%		        den(s)
%
%	Vector DEN specifies the coefficients of the denominator in 
%	descending powers of s.  Matrix NUM indicates the numerator 
%	coefficients with as many rows as there are outputs.  The zero
%	locations are returned in the columns of matrix Z, with as many 
%	columns as there are rows in NUM.  The pole locations are returned
%	in column vector P, and the gains for each numerator transfer 
%	function in vector K. 
%	
%	See also: ZP2TF.

%	Clay M. Thompson 11-6-90 
%	Revised ACWG 1-17-90
%	Copyright (c) 1986-93 by the Mathworks, Inc.


[z,p,k] = tf2zp(num,den);

%  Stripper imaginrdelen fra sammenfallende rtter p 
%  og like ved reell akse:
n=max(size(p));

if n > 1
for m=1:1:n
     if (imag(p(m)/real(p(m)<1e-3))) p(m)=real(p(m));
     end
  end
end

